@@ -46,6 +46,9 @@ def compute_statistical_lengths(bw, daplha=9):
 
     angles = np.arange(0, 180, daplha)
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+
     feret_diameters = np.zeros(angles.shape, dtype='int')
     martin_diameters = np.zeros(angles.shape, dtype='int')
     nassenstein_diameters = np.zeros(angles.shape, dtype='int')
@@ -106,6 +109,10 @@ def nassenstein(bw):
     assert bw.dtype == 'bool', "`bw` should be boolean"
     assert bw.ndim == 2, "`bw` must be 2-dimensional array"
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+        return 0, np.array([])
+
     bw_pad = np.pad(bw, pad_width=1, mode='constant', constant_values=False)
 
     # find lowest row
@@ -189,6 +196,10 @@ def feret(bw):
     assert bw.dtype == 'bool', "`bw` must be of dtype 'bool'."
     assert bw.ndim == 2, "`bw` must be 2-dimensional array"
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+        return 0, np.array([])
+
     n_pixels_x = bw.shape[0]
 
     # "squeeze" bw in y-direction into one column
@@ -252,6 +263,10 @@ def martin(bw, area_share_from_bottom=0.5):
     assert (area_share_from_bottom >= 0 and
             area_share_from_bottom <= 1), "Area share must be in interval [0, 1]."
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+        return 0, np.array([])
+
     if area_share_from_bottom == 0 or area_share_from_bottom == 1:
         warnings.warn("Return 0 since area share = {:0.1f}".format(
             area_share_from_bottom))
@@ -319,6 +334,10 @@ def find_all_chords(bw):
     assert bw.dtype == 'bool', "`bw` must be of dtype 'bool'."
     assert bw.ndim == 2, "`bw` must be 2-dimensional array"
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+        return np.array([]), np.array([])
+
     all_chords = np.array([], dtype='int')
     all_edgepoints = np.zeros((0, 2), dtype='int')
 
@@ -399,6 +418,10 @@ def find_max_chord(bw):
     assert bw.dtype == 'bool', "`bw` must be of dtype 'bool'."
     assert bw.ndim == 2, "`bw` must be 2-dimensional array"
 
+    if np.count_nonzero(bw) == 0:
+        warnings.warn("`bw` is empty.")
+        return 0, np.array([])
+
     all_chords, all_edgepoints = find_all_chords(bw)
     max_chord, idx = _max_chord_from_all_chords(
         all_chords, all_edgepoints)
@@ -433,7 +456,7 @@ def distribution_parameters(distribution):
     distribution = distribution.ravel()
 
     if len(distribution) == 0:
-        warnings.warn("`distribution` has length 0 --> return None.")
+        warnings.warn("`distribution` is empty --> return None.")
         return None, None, None, None, None, None
     max_value = distribution.max()
     min_value = distribution.min()
